==> haskell-tasty-lua-0.2.0.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-lua
version: 0.2.0.1
id: tasty-lua-0.2.0.1-EU2VYTdObL7AJeNZNcVESW
key: tasty-lua-0.2.0.1-EU2VYTdObL7AJeNZNcVESW
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/tasty-lua
synopsis: Write tests in Lua, integrate into tasty.
description:
    Allow users to define tasty tests from Lua.
category: Foreign
abi: 7c67f077b89769af585dbaa5d01f198d
exposed: True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Core Test.Tasty.Lua.Module
    Test.Tasty.Lua.Translate
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-lua-0.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-lua-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-lua-0.2.0.1
hs-libraries: HStasty-lua-0.2.0.1-EU2VYTdObL7AJeNZNcVESW
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    file-embed-0.0.11-4IE3sw0bCLQ7xXwEGMUYke
    hslua-1.0.3.2-5h9nVB07WjnrmFtle4MfG
    tasty-1.2.3-9rbI7SmrRn85ofgbCsxp2n text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html: /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-lua-0.2.0.1-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-lua.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-lua
version: 0.2.0.1
id: tasty-lua-0.2.0.1-L47wp4XH8xe4MvkjLIogLN
key: tasty-lua-0.2.0.1-L47wp4XH8xe4MvkjLIogLN
license: MIT
copyright: Albert Krewinkel <albert+hslua@zeitkraut.de>
maintainer: albert+hslua@zeitkraut.de
author: Albert Krewinkel
homepage: https://github.com/hslua/tasty-lua
synopsis: Write tests in Lua, integrate into tasty.
description:
    Allow users to define tasty tests from Lua.
category: Foreign
abi: 28cbfba28632da7a9bd2d3e455c5f51e
exposed: True
exposed-modules:
    Test.Tasty.Lua Test.Tasty.Lua.Core Test.Tasty.Lua.Module
    Test.Tasty.Lua.Translate
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-lua-0.2.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-lua-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-lua-0.2.0.1
hs-libraries: HStasty-lua-0.2.0.1-L47wp4XH8xe4MvkjLIogLN
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    file-embed-0.0.11.1-1DkjC7VmQhQFLvxtpUIE3o
    hslua-1.0.3.2-2Si3U5CCYPv3P6HZtLHMkP
    tasty-1.2.3-HVtsfsVGsB3ReS9DqXVTz text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-tasty-lua/html/tasty-lua.haddock
haddock-html: /usr/share/doc/haskell-tasty-lua/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
